from setuptools import setup, find_packages

setup(name="ops-shuv",
      version="0.3",
      description="this contains some kind operations in it.",
      author="shuvam mandal",
      author_email="shuvammandal121@gmail.com",
      packages=["ops-shuv"],
      requires=[],
      )