def add(a,b):
    print('this is the addition',a+b)
def sub(a,b):
    print('this is the subtraction',a-b)
def mul(a,b):
    print('this is the multiplication',a*b)
def div(a,b):
    print('this is the division', a//b)



